package com.ruoyi.project.ehs.mapper;

import java.util.List;
import com.ruoyi.framework.aspectj.lang.annotation.DataScope;
import com.ruoyi.project.ehs.domain.TSafetyapprcont;

/**
 * 安全批文主要内容Mapper接口
 * 
 * @author ruoyi
 * @date 2020-11-27
 */
public interface TSafetyapprcontMapper 
{
    /**
     * 查询安全批文主要内容
     * 
     * @param id 安全批文主要内容ID
     * @return 安全批文主要内容
     */
    public TSafetyapprcont selectTSafetyapprcontById(Long id);

    /**
     * 查询安全批文主要内容列表
     * 
     * @param tSafetyapprcont 安全批文主要内容
     * @return 安全批文主要内容集合
     */
    public List<TSafetyapprcont> selectTSafetyapprcontList(TSafetyapprcont tSafetyapprcont);

    /**
     * 新增安全批文主要内容
     * 
     * @param tSafetyapprcont 安全批文主要内容
     * @return 结果
     */
    public int insertTSafetyapprcont(TSafetyapprcont tSafetyapprcont);

    /**
     * 修改安全批文主要内容
     * 
     * @param tSafetyapprcont 安全批文主要内容
     * @return 结果
     */
    public int updateTSafetyapprcont(TSafetyapprcont tSafetyapprcont);

    /**
     * 删除安全批文主要内容
     * 
     * @param id 安全批文主要内容ID
     * @return 结果
     */
    public int deleteTSafetyapprcontById(Long id);

    /**
     * 批量删除安全批文主要内容
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteTSafetyapprcontByIds(Long[] ids);
}
